#!/bin/bash

echo -e "XXXXXXX\tBr\tBr.Br" \
    | smi_isomorphism
